package Bundle::AMBS;

$VERSION = '0.02';

=head1 NAME

Bundle::AMBS - install all modules by AMBS

=head1 SYNOPSIS

cpan Bundle::AMBS

=head1 CONTENTS

Acme::Lisp

Biblio::Catalog

Biblio::Thesaurus

Biblio::WebPortal

Config::AutoConf

Lingua::EN::NamedEntity

Lingua::PT::Abbrev

Lingua::PT::PLN

Lingua::PT::PLNbase

Lingua::PT::ProperNames

Search::Glimpse

String::Tokeniser

Tie::Cvs

Tie::Ispell

Text::RewriteRules

XML::DT

XML::TMX

XML::XCES

=head1 AUTHOR

Alberto Simes, C<< <ambs@cpan.org> >>

=head1 COPYRIGHT & LICENSE

Copyright 2004-2005 Alberto Simes, All Rights Reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1; # End of Bundle::AMBS
